@@ -91,6 +91,16 @@ class DataSet:
         self.qp_data = result['csv']
         self.dataset_type = 'quantipy'
 
+    @add_data
+    def write_spss(self, file_path, data_params, **kwargs):
+        payload = {}
+        files, payload = self.prepare_post_params(data_params, {})
+        response = self.tally.post_request('tally', 'convert_data_to_sav', payload, files)
+        file = open(file_path, "wb")
+        file.write(response.content)
+        file.close()
+        return response
+
     def use_quantipy(self, meta_json, data_csv):
         with open(meta_json) as json_file:
             self.qp_meta = json.dumps(json.load(json_file))
@@ -193,6 +203,7 @@ class DataSet:
         payload['params'] = params
         return (files, payload)
 
+    @valid_params(['crosstabs', 'x', 'y', 'w', 'f', 'ci', 'stats', 'sig_level', 'decimals', 'base', 'painted', 'rebase', 'factors', 'format', 'add_format_column'])
     @add_data
     @format_response
     def crosstab(self, data_params=None, **kwargs):
@@ -211,7 +222,6 @@ class DataSet:
         datasources={"one":{"meta":payload.pop('meta'), "data":payload.pop('data')}}
         payload['params']['datasources'] = datasources
         response = self.tally.post_request('tally', 'joined_crosstab', payload, files)
-        import pdb; pdb.set_trace()
         json_dict = json.loads(response.content)
         if 'result' in json_dict.keys():
             return json_dict
@@ -282,8 +292,6 @@ class DataSet:
         files, payload = self.prepare_post_params(data_params, kwargs)
         payload = kwargs
         response = self.tally.post_request('tally', 'build_excel_from_dataframes', payload, files)
-        if 'error' in response:
-            return response
         file = open(filename, "wb")
         file.write(response.content)
         file.close()
